<?xml version="1.0" encoding="utf-8"?>

<!DOCTYPE xsl:stylesheet [
<!ENTITY timestamp SYSTEM "timestamp.txt">
<!ENTITY datestamp SYSTEM "datestamp.txt">
<!ENTITY it_settings SYSTEM "it_settings.txt">
<!ENTITY seal_ent SYSTEM "seal_ent.txt">
<!ENTITY dtd_path_1 SYSTEM "dtd_path_1.txt">
]>

<!-- created by Michael Ferrando at the Library of Congress for converting EAD 1.0 to EAD 2002 DAO to DAOGRP -->

<!-- This stylesheet has been created primarily to meet the needs of the Library of Congress EAD users. This stylesheet is provided 'as-is', without any express or implied warranty. -->

<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xs="http://www.w3.org/2001/XMLSchema" 
  xmlns:saxon="http://icl.com/saxon"
  extension-element-prefixes="saxon" 
	exclude-result-prefixes="xs"
>
<xsl:output 
	version="1.0" 
	method="xml" 
	indent="yes" 
	encoding="UTF-8" 
	omit-xml-declaration="no" 
	standalone="no" 
	media-type="text/xml"
/>

<xsl:strip-space elements="accessrestrict accruals acqinfo address altformavail appraisal arc archdesc arrangement bibliography bioghist blockquote c c01 c02 c03 c04 c05 c06 c07 c08 c09 c10 c11 c12 change chronitem chronlist colspec controlaccess custodhist dao daodesc daogrp daoloc defitem descgrp did div dsc ead eadheader editionstmt eventgrp extptr extptrloc filedesc fileplan frontmatter index indexentry lb linkgrp list listhead namegrp note notestmt odd originalsloc otherfindaid phystech prefercite processinfo profiledesc ptr ptrgrp ptrloc publicationstmt relatedmaterial revisiondesc row scopecontent separatedmaterial seriesstmt table tbody tgroup thead titlepage titlestmt userestrict"/>
<xsl:preserve-space elements="abbr abstract addressline archref author bibref bibseries container corpname creation date descrules dimensions eadid edition emph entry event expan extent extref extrefloc famname function genreform geogname head head01 head02 imprint item label langmaterial language langusage legalstatus materialspec name num occupation origination p persname physdesc physfacet physloc publisher ref refloc repository resource runner sponsor subarea subject subtitle title titleproper unitdate unitid unittitle"/>

<xsl:variable name="urn_x_2">
	<xsl:value-of select="normalize-space(//eadid[1])"/>
</xsl:variable>

<!-- (variable for element = eadid/@identifier) -->
<xsl:variable name="urn_x_1">
	<xsl:choose>
		<xsl:when test="
				substring(
					$urn_x_2, 
					string-length($urn_x_2) -8,
					1
				)='.'">
				<xsl:variable name="urn_st_l_x">
					<xsl:call-template name="get_urn_string">
						<xsl:with-param name="urn_xx_s" select="
								substring(
									$urn_x_2, 
									1,
									string-length($urn_x_2) -9
								)
						"/>
						<xsl:with-param name="urn_ct_x">0</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="number($urn_st_l_x + 9)"/>
		</xsl:when>
		<xsl:otherwise>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:variable name="report_eadheader_dom">
	<xsl:value-of select="name(//revisiondesc)"/>
</xsl:variable>

<xsl:variable name="report_revisiondesc_dom">
	<xsl:for-each select="//revisiondesc/*">
		<xsl:value-of select="name()"/>
		<xsl:text>;</xsl:text>
	</xsl:for-each>
</xsl:variable>

<xsl:variable name="x_timestamp">
	<xsl:variable name="x_timestamp_x">
		<xsl:text>&timestamp;</xsl:text>
	</xsl:variable>
	<xsl:variable name="x_timestamp_n" select="
		translate(normalize-space($x_timestamp_x), 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')
	"/>
	<xsl:value-of select="
		translate($x_timestamp_n, 
		'0123456789/abcdefghijklmnopqrstuvwxyz ()-:', 
		'0123456789'
		)
	"/>
</xsl:variable>

<xsl:variable name="x_datestamp">
	<xsl:text>&datestamp;</xsl:text>
</xsl:variable>

<xsl:variable name="x_it_settings">
	<xsl:text>&it_settings;</xsl:text>
</xsl:variable>

<xsl:variable name="x_idate">
	<xsl:variable 
		name="n_x_it_settings" 
		select="translate($x_it_settings, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')
	"/>
	<xsl:variable name="qt">"</xsl:variable>
	<xsl:variable name="x" select="concat($qt, 'idate', $qt, '=', $qt)"/>
	<xsl:value-of select="
		number(
			substring-before(
				substring-after($n_x_it_settings, $x),
				 $qt
			)
		 + 1)
	"/>
</xsl:variable>
<!-- DOS not changed by Windows Regional settings -->
<!-- echo %date% = XX/XX/XXXX -->
<!-- iDate = 1 = DD/MM/YYYY -->
<!-- iDate = 0 = MM/DD/YYYY -->
<!-- normalize-space (x_timestamp) -->
<xsl:variable name="n_x_datestamp">
<xsl:variable name="nn_d" select="
translate(normalize-space($x_datestamp), 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')
"/>
<xsl:value-of select="
translate($nn_d, 
'0123456789/abcdefghijklmnopqrstuvwxyz ()-:', 
'0123456789/'
)
"/>
</xsl:variable>
<!-- ?? -->
<xsl:variable name="x_1" select="
substring(
	$n_x_datestamp, 
	number(string-length($n_x_datestamp) - 9), 
	2
)"/>
<!-- ?? -->
<xsl:variable name="x_2" select="
substring(
	$n_x_datestamp, 
	number(string-length($n_x_datestamp) - 6), 
	2
)"/>
<!-- year -->
<xsl:variable name="x_3" select="
substring(
	$n_x_datestamp, 
	number(string-length($n_x_datestamp) - 3), 
	string-length($n_x_datestamp)
)"/>

<xsl:variable name="x_idate_att">
	<xsl:choose>
		<xsl:when test="string-length($x_idate)=1">
			<xsl:if test="$x_idate=1">
					<xsl:value-of select="$x_3"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="$x_1"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="$x_2"/>
			</xsl:if>
			<xsl:if test="$x_idate=2">
					<xsl:value-of select="$x_3"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="$x_2"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="$x_1"/>
			</xsl:if>
		</xsl:when>
		<xsl:otherwise>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:variable name="x_dtd_path_1">
	<xsl:variable name="dtd_path_1x">
		<xsl:text>&dtd_path_1;</xsl:text>
	</xsl:variable>
	<xsl:value-of select="normalize-space($dtd_path_1x)"/>
</xsl:variable>

<xsl:strip-space elements="*"/>

<!--(variable for element = eadid/identifier)-->
<xsl:variable name="urn_eadid_2002">
	<xsl:value-of select="concat('hdl:loc', substring(normalize-space(//eadid[1]), string-length(normalize-space(//eadid[1]))- $urn_x_1, string-length(normalize-space(//eadid[1]))))"/>
</xsl:variable>

<xsl:param name="replace"/>
<!-- root template -->
<xsl:template match="/">
	<xsl:text>
</xsl:text>
	<xsl:comment>
		<xsl:value-of select="concat(' Transformed with ', $replace, '.xsl ')"/>
	</xsl:comment>
	<xsl:for-each select="comment()">
		<xsl:text>
</xsl:text>
		<xsl:comment>
			<xsl:value-of select="."/>
		</xsl:comment>
	</xsl:for-each>
	<xsl:text>
</xsl:text>
	<xsl:call-template name="doctype_2002"/>

<saxon:output 
	href="dao_report_{
								concat(
									translate($n_x_datestamp, '/', ''), 
									'.', 
									$x_timestamp
								)
							}.htm" 
	version="1.0" 
	indent="yes" 
	encoding="UTF-8" 
	omit-xml-declaration="no" 
	standalone="no" 
  doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" 
  doctype-system="http://www.w3.org/TR/html4/loose.dtd"
	media-type="text/html"
>
<HTML>
<HEAD>
<TITLE>EAD 2002 LC Practices Report: &lt;DAO&gt; changed to &lt;DAOGRP&gt;</TITLE>
<xsl:text disable-output-escaping="yes">&lt;</xsl:text>
<xsl:text>META HTTP-EQUIV="Content-Type" CONTENT="text/html;charset=utf-8"</xsl:text>
<xsl:text disable-output-escaping="yes">&gt;</xsl:text>
<STYLE TYPE="text/css">
	EM { display: none }
</STYLE>
</HEAD>
<BODY>
<TABLE WIDTH="88%">
<TR>
<TD>
<H1>EAD 2002 LC Practices Report: &lt;DAO&gt; changed to &lt;DAOGRP&gt;</H1>
<P><A name="bogus_x">&#160;</A></P>
	<H2>Date: </H2>
<BLOCKQUOTE>
<UL>
<LI>
<A>
						<xsl:if test="string-length($x_idate_att)!=0">
								<xsl:attribute name="name">
									<xsl:value-of select="$x_idate_att"/>
								</xsl:attribute>
								<xsl:value-of select="$x_idate_att"/>
							</xsl:if>
<xsl:text>&#160;</xsl:text>
</A>
							<xsl:if test="string-length($x_idate_att)=0">
								<xsl:value-of select="$n_x_datestamp"/>
							</xsl:if>
</LI>
</UL>
</BLOCKQUOTE>
<P><A name="bogus_x">&#160;</A></P>
<H2>Title: </H2>
<BLOCKQUOTE>
<UL>
<xsl:apply-templates select="//archdesc[1]/did[1]/unittitle" mode="report_deprecated_element"/>
</UL>
</BLOCKQUOTE>
<P><A name="bogus_x">&#160;</A></P>
<H2>Document ID:</H2>
<BLOCKQUOTE>
<UL>
<xsl:apply-templates select="//eadid[1]" mode="report_deprecated_element"/>
</UL>
</BLOCKQUOTE>
<P><A name="bogus_x">&#160;</A></P>
<H2>XSL stylesheet:</H2>
<BLOCKQUOTE>
<UL>
<LI>
<xsl:value-of select="$replace"/>
<xsl:text>.xsl (created by Michael Ferrando at the Library of Congress)</xsl:text>
</LI>
</UL>
</BLOCKQUOTE>
<P><A name="bogus_x">&#160;</A></P>
<H2>Note:</H2>
<BLOCKQUOTE>
<UL>
<LI>
Line number refer to XML document ?_x.xml (example: SX.bat: mu001001.sgm &gt; mu001001_x.xml)
</LI>
<LI>Some @* (example: @inline) are generated into the sgm document when converted from SGML to XML (SX.bat) as required by the DTD</LI>
<LI>The • appear only in the HTML report.</LI>
<LI><A HREF="http://www.loc.gov/ead/tglib1998/tlhome.html">EAD Tag Library for Version 1.0</A></LI>
<LI><A HREF="http://www.loc.gov/ead/tglib/index.html">EAD Tag Library for Version 2002</A></LI>
<LI><A HREF="http://lcweb.loc.gov/ead/practices/lcpractices.html">Library of Congress EAD 1.0 best practices current draft</A></LI>
<LI><A HREF="http://www.loc.gov/ead/practices/lcp2002.html">Library of Congress EAD 2002 best practices current draft</A></LI>
</UL>
</BLOCKQUOTE>
<P><A name="bogus_x">&#160;</A></P>
<H2>Conversion statistics: </H2>
                  <TABLE>
									<TR>
<TD WIDTH="35%"><H3>Line #</H3></TD>
<TD WIDTH="65%"><H3>.....Comments</H3></TD>
									</TR>
									</TABLE>
<HR NOSHADE="NOSHADE"/>

<xsl:variable name="doctype_report_nodes">
	<xsl:call-template name="doctype_2002"/>
</xsl:variable>
<P align="left"><A name="bogus_x">&#160;</A></P>
<H4>&lt;!DOCTYPE&gt; (inserted by stylesheet)</H4>
<BLOCKQUOTE>
<P>Note: The <B>System Identifier</B> value is supplied by the contents of <B>dtd_path_1.txt</B>. If the user desires to change the path, edit <B>dtd_path_1.txt</B> accordingly. <I>See</I>: <B>sample_dtd_path_1.txt</B> for an example of full path syntax.</P>
<P>Note: The Seal entity is produced from the contents of <B>seal_ent.txt</B>. Edit <B>seal_ent.txt</B> according to your particular institution image file type and location. <B>seal_ent.txt</B> is designed to generate 1 and only 1 entity. <B>Do not</B> add other entities to this file.</P>
<P><xsl:value-of select="$doctype_report_nodes"/></P>
</BLOCKQUOTE>


<xsl:if test="
		string-length(
			concat(
				unparsed-entity-uri(//*[@entityref]/@entityref), 
				unparsed-entity-uri(//*[@href]/@href) 
			)
		)!=0
">
<P><A name="bogus_x">&#160;</A></P>
<H4>&lt;!ENTITY&gt; (unparsed)</H4>
<BLOCKQUOTE>
<P>Note: With the exception of the Seal image (see above), any <B>unparsed</B> entity must be added <B>by the user</B> to the DOCTYPE of ?_x.xml from the DOCTYPE of ?.xml.</P>
</BLOCKQUOTE>


<xsl:for-each select="
		//*[string-length(
			concat(
				unparsed-entity-uri(@entityref), 
				unparsed-entity-uri(@href) 
			)
		)!=0]
">
	<P><A name="bogus_x">&#160;</A></P>
	<BLOCKQUOTE>
	<P>===Begin build reproduction===</P>
	<UL>
	<LI>
<xsl:text>line # </xsl:text>
<xsl:value-of select="saxon:line-number()"/>
	</LI>
	<LI>
<xsl:text>URI = ' </xsl:text>
<xsl:value-of select="			concat(
				unparsed-entity-uri(@entityref), 
				unparsed-entity-uri(@href) 
			)"/>
<xsl:text> '</xsl:text>
	</LI>
	<xsl:apply-templates select="self::*" mode="report_deprecated_element"/>
	</UL>
	<P>===End build reproduction===</P>
	</BLOCKQUOTE>

</xsl:for-each>

</xsl:if>

<P><A name="bogus_x">&#160;</A></P>
<H4>&lt;ELEMENTS&gt;</H4>

<!-- <dao> -->
<xsl:choose>
<xsl:when test="//dao">
<P><A name="bogus_x">&#160;</A></P>
<H4>&lt;dao&gt;</H4>

<xsl:apply-templates select="//dao" mode="report_element"/>
</xsl:when>
<xsl:otherwise>
<P><A name="bogus_x">&#160;</A></P>
<H4>No &lt;dao&gt; elements present</H4>

</xsl:otherwise>
</xsl:choose>
<HR/>
<P><A name="bogus_x">&#160;</A></P>
<H4>END OF LINE</H4>

</TD>
</TR>
</TABLE>
</BODY>
</HTML>

</saxon:output>

	<xsl:text>
</xsl:text>
		<xsl:apply-templates select="*"/>
</xsl:template>


<!-- doctype template -->
<xsl:template name="doctype_2002">
<xsl:text>
</xsl:text>
<xsl:text disable-output-escaping="yes">&lt;!DOCTYPE ead PUBLIC "+//ISBN 1-931666-00-8//DTD ead.dtd (Encoded Archival Description (EAD) Version 2002)//EN" "</xsl:text>
<xsl:value-of select="$x_dtd_path_1"/>
<xsl:text>" [</xsl:text>
<xsl:text>
	</xsl:text>
<xsl:text disable-output-escaping="yes">&lt;&seal_ent;&gt;</xsl:text>
<xsl:text>
</xsl:text>
<xsl:text disable-output-escaping="yes">]&gt;</xsl:text>
</xsl:template>

<xsl:template match="*">
	<xsl:element name="{name()}">
		<xsl:apply-templates select="@* | * | processing-instruction() | comment() | text()">
			<xsl:with-param name="nm_element" select="name()"/>
		</xsl:apply-templates>
	</xsl:element>
</xsl:template>

<xsl:template match="dao">
 	<xsl:element name="daogrp">
		<xsl:element name="daoloc">
			<xsl:apply-templates select="@*">
				<xsl:with-param name="nm_element" select="name()"/>
			</xsl:apply-templates>
			<xsl:attribute name="linktype">locator</xsl:attribute>
			<xsl:apply-templates select="* | processing-instruction() | comment() | text()"/>
		</xsl:element>
	</xsl:element>
</xsl:template>

<!-- wildcard attribute @* template -->
<xsl:template match="@*">
	<xsl:param name="nm_element"/>
	<xsl:choose>
		<xsl:when test="string-length(.)=0">
		</xsl:when>
		<xsl:otherwise>
			<xsl:attribute name="{name()}">
				<xsl:choose>
					<xsl:when test="$nm_element='dao' and name()='linktype'">
						<xsl:text>locator</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- wildcard attribute @* template -->
<xsl:template match="@actuate | @show">
	<xsl:param name="nm_element"/>
	<xsl:choose>
		<xsl:when test="string-length(.)=0">
		</xsl:when>
		<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$nm_element='dao'">
					</xsl:when>
					<xsl:otherwise>
			<xsl:attribute name="{name()}">
						<xsl:value-of select="."/>
			</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- comment() | processing-instruction() | text() template -->
<xsl:template match="comment() | processing-instruction() | text()">
	<xsl:copy>
		<xsl:apply-templates select="comment() | processing-instruction() | text()"/>
	</xsl:copy>
</xsl:template>

<!--(element = dao)-->
<xsl:template match="dao" mode="report_element">
	<P><A name="bogus_x">&#160;</A></P>
<xsl:value-of select="saxon:line-number()"/>
<xsl:text> .....</xsl:text>
<xsl:text>EAD 2002 LC practices changing </xsl:text>
<xsl:text>&lt;dao&gt; to &lt;daogrp&gt;
</xsl:text>
<BLOCKQUOTE>
<P>Note: Attributes dao/@show and dao/@actuate will be removed without substitution as recommended by LC practices.</P>
</BLOCKQUOTE>
<BLOCKQUOTE>
<P><B>Original nodes</B></P>
<P>===Begin <I>original</I> build reproduction===</P>
<UL>

<xsl:text disable-output-escaping="yes">&lt;LI&gt;</xsl:text>
<xsl:text>&lt;</xsl:text>
<xsl:value-of select="name()"/>
	<xsl:apply-templates select="@*" mode="report_deprecated_element"/>
<xsl:text>&gt;</xsl:text>
<xsl:apply-templates select="* | text()" mode="report_deprecated_element"/>
<xsl:text>&lt;/</xsl:text>
<xsl:value-of select="name()"/>
<xsl:text>&gt;</xsl:text>

</UL>
<P>===End <I>original</I> build reproduction===</P>
</BLOCKQUOTE>
<BLOCKQUOTE>
<P><B>Changed to LC practices</B></P>
<P>===Begin <I>changed</I> build reproduction===</P>
<UL>
<xsl:text disable-output-escaping="yes">&lt;LI&gt;</xsl:text>
<xsl:text>&lt;daogrp&gt;</xsl:text>
<xsl:text disable-output-escaping="yes">&lt;LI&gt;</xsl:text>
<xsl:text>&lt;daoloc</xsl:text>
	<xsl:apply-templates select="@*" mode="report_deprecated_element_2">
		<xsl:with-param name="nm_element" select="name()"/>
	</xsl:apply-templates>
<xsl:text>&gt;</xsl:text>
<xsl:apply-templates select="* | text()" mode="report_deprecated_element"/>
<xsl:text>&lt;/daoloc&gt;</xsl:text>
<xsl:text>&lt;/daogrp&gt;</xsl:text>
</UL>
<P>===End <I>changed</I> build reproduction===</P>
</BLOCKQUOTE>

</xsl:template>

<!-- Report: wildcard @* template -->
<xsl:template match="@*" mode="report">
</xsl:template>

<!-- Report: reproduce deprecated element -->
<xsl:template match="*" mode="report_deprecated_element">
<xsl:text disable-output-escaping="yes">&lt;LI&gt;</xsl:text>
<xsl:text>&lt;</xsl:text>
<xsl:value-of select="name()"/>
	<xsl:apply-templates select="@*" mode="report_deprecated_element">
		<xsl:with-param name="nm_element" select="name()"/>
	</xsl:apply-templates>
	<xsl:choose>
		<xsl:when test="child::* or string-length(.)!=0">
<xsl:text>&gt;</xsl:text>
<xsl:apply-templates select="* | text()" mode="report_deprecated_element"/>
<xsl:text>&lt;/</xsl:text>
<xsl:value-of select="name()"/>
<xsl:text>&gt;</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:text>/&gt;</xsl:text>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<!-- Report: reproduce deprecated element -->
<xsl:template match="*" mode="report_deprecated_element">
<xsl:text disable-output-escaping="yes">&lt;LI&gt;</xsl:text>
<xsl:text>&lt;</xsl:text>
<xsl:value-of select="name()"/>
	<xsl:apply-templates select="@*" mode="report_deprecated_element">
		<xsl:with-param name="nm_element" select="name()"/>
	</xsl:apply-templates>
	<xsl:choose>
		<xsl:when test="child::* or string-length(.)!=0">
<xsl:text>&gt;</xsl:text>
<xsl:apply-templates select="* | text()" mode="report_deprecated_element"/>
<xsl:text>&lt;/</xsl:text>
<xsl:value-of select="name()"/>
<xsl:text>&gt;</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:text>/&gt;</xsl:text>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<!-- Report: reproduce deprecated element/@* -->
<xsl:template match="@*" mode="report_deprecated_element">
<xsl:param name="nm_element"/>
<xsl:text> </xsl:text>
<xsl:value-of select="name()"/>
<xsl:text>="</xsl:text>
	<xsl:choose>
		<xsl:when test="$nm_element='dao' and name()='linktype'">
			<xsl:text>locator</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
<xsl:text>"</xsl:text>
</xsl:template>

<!-- Report: reproduce deprecated element/text() -->
<xsl:template match="text()" mode="report_deprecated_element">
<xsl:value-of select="."/>
</xsl:template>

<!-- Report: these templates will eradicate dao/@actuate | @show -->
<!-- Report: reproduce deprecated element -->
<xsl:template match="*" mode="report_deprecated_element_2">
<xsl:text disable-output-escaping="yes">&lt;LI&gt;</xsl:text>
<xsl:text>&lt;</xsl:text>
<xsl:value-of select="name()"/>
	<xsl:apply-templates select="@*" mode="report_deprecated_element_2">
		<xsl:with-param name="nm_element" select="name()"/>
	</xsl:apply-templates>
	<xsl:choose>
		<xsl:when test="child::* or string-length(.)!=0">
<xsl:text>&gt;</xsl:text>
<xsl:apply-templates select="* | text()" mode="report_deprecated_element_2"/>
<xsl:text>&lt;/</xsl:text>
<xsl:value-of select="name()"/>
<xsl:text>&gt;</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:text>/&gt;</xsl:text>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="@*" mode="report_deprecated_element_2">
<xsl:param name="nm_element"/>
<xsl:text> </xsl:text>
<xsl:value-of select="name()"/>
<xsl:text>="</xsl:text>
	<xsl:choose>
		<xsl:when test="$nm_element='dao' and name()='linktype'">
			<xsl:text>locator</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
<xsl:text>"</xsl:text>
</xsl:template>

<!-- Report: reproduce deprecated element/@* -->
<xsl:template match="@actuate | @show" mode="report_deprecated_element_2">
<xsl:param name="nm_element"/>
	<xsl:choose>
		<xsl:when test="$nm_element='dao'">
		</xsl:when>
		<xsl:otherwise>
<xsl:text> </xsl:text>
<xsl:value-of select="name()"/>
<xsl:text>="</xsl:text>
			<xsl:value-of select="."/>
<xsl:text>"</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Report: reproduce deprecated element/text() -->
<xsl:template match="text()" mode="report_deprecated_element_2">
<xsl:value-of select="."/>
</xsl:template>

<!-- find second dot for handle of eadid node text -->
<xsl:template name="get_urn_string">
	<xsl:param name="urn_xx_s"/>
	<xsl:param name="urn_ct_x"/>
	<xsl:choose>
		<xsl:when test="substring($urn_xx_s, string-length($urn_xx_s), 1)!='.'">
			<xsl:call-template name="get_urn_string">
				<xsl:with-param name="urn_xx_s" select="
						substring(
							$urn_xx_s, 
							1, 
							string-length($urn_xx_s)-1
						)
				"/>
				<xsl:with-param name="urn_ct_x" select="number($urn_ct_x + 1)"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$urn_ct_x"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>